==> cantata_2.5.3.orig.tar.gz: cantata-2.5.3/3rdparty/solid-lite/backends/wmi/wmiblock.cpp <==
/*
    Copyright 2006 Kevin Ottens <ervin@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "wmiblock.h"

#include "wmidevice.h"

using namespace Solid::Backends::Wmi;

Block::Block(WmiDevice *device)
    : DeviceInterface(device)
{

}

Block::~Block()
{

}

int Block::deviceMajor() const
{
    return 0;
}

int Block::deviceMinor() const
{
    return 0;
}

QString Block::device() const
{
    QString drive;
    switch(m_device->type()){
    case Solid::DeviceInterface::StorageVolume:
    {
        drive = WmiDevice::win32LogicalDiskByDiskPartitionID(m_device->property("DeviceID").toString()).getProperty("DeviceID").toString();
    }
        break;
    case Solid::DeviceInterface::OpticalDrive:
    case Solid::DeviceInterface::OpticalDisc:
        drive = m_device->property("Drive").toString();
        break;
    }
    return drive;
}

#include "backends/wmi/moc_wmiblock.cpp"

==> cantata-3.3.0.tar.gz: cantata-3.3.0/3rdparty/solid-lite/backends/wmi/wmiblock.cpp <==
/*
    Copyright 2006 Kevin Ottens <ervin@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "wmiblock.h"

#include "wmidevice.h"

using namespace Solid::Backends::Wmi;

Block::Block(WmiDevice* device)
	: DeviceInterface(device)
{
}

Block::~Block()
{
}

int Block::deviceMajor() const
{
	return 0;
}

int Block::deviceMinor() const
{
	return 0;
}

QString Block::device() const
{
	QString drive;
	switch (m_device->type()) {
	case Solid::DeviceInterface::StorageVolume: {
		drive = WmiDevice::win32LogicalDiskByDiskPartitionID(m_device->property("DeviceID").toString()).getProperty("DeviceID").toString();
	} break;
	case Solid::DeviceInterface::OpticalDrive:
	case Solid::DeviceInterface::OpticalDisc:
		drive = m_device->property("Drive").toString();
		break;
	}
	return drive;
}

#include "backends/wmi/moc_wmiblock.cpp"
